@@ -238,36 +238,47 @@ sub finddoc  {
       }
     }
     
-    if (  @match > 1   and   !$subfield  ) {
-      print $out "\n\n=head1 MULTIPLE MATCHES FOR HELP TOPIC '$topic':\n\n=head1\n\n=over 3\n\n";
-      my $i=0;
-      for my $m ( @match ) {
-	printf $out "\n=item [%d]\t%-30s %s%s\n\n", ++$i, $m->[0], $m->[1]{Module} && "in ", $m->[1]{CustomFile} || $m->[1]{Module};
-      }
-      print $out "\n=back\n\n=head1\n\n To see item number \$n, use 'help ${topic}\[\$n\]'. \n\n=head1 Displaying item 1:\n\n=head1 --------------------------------------\n\n=cut\n\n";
-    }
-    
-    my $m = shift @match;
-    
-    my $Ref = $m->[1]{Ref};
-    if ( $Ref =~ /^(Module|Manual|Script): / ) {
-      my $in = IO::File->new("<$m->[1]{File}");
-      print $out join("",<$in>);
-    } else {
-      if(defined $m->[1]{CustomFile}) {
-	
-	my $parser= new PDL::Pod::Parser;
-	print $out "=head1 Autoload file \"".$m->[1]{CustomFile}."\"\n\n";
-	$parser->parse_from_file($m->[1]{CustomFile},$out);
-	print $out "\n\n=head2 Docs from\n\n".$m->[1]{CustomFile}."\n\n";
-	
-      } else {
-	
-	print $out "=head1 Module ",$m->[1]{Module}, "\n\n";
-	$PDL::onlinedoc->funcdocs($m->[0],$out);
-	
-      }
-      
+    my $num_pdl_pod_matches = scalar @match;
+    my $pdl_pod_matchnum = 0;
+
+    while (@match) {
+       $pdl_pod_matchnum++;
+
+       if (  @match > 1   and   !$subfield  ) {
+          print $out "\n\n=head1 MULTIPLE MATCHES FOR HELP TOPIC '$topic':\n\n=head1\n\n=over 3\n\n";
+          my $i=0;
+          for my $m ( @match ) {
+             printf $out "\n=item [%d]\t%-30s %s%s\n\n", ++$i, $m->[0], $m->[1]{Module} && "in ", $m->[1]{CustomFile} || $m->[1]{Module};
+          }
+          print $out "\n=back\n\n=head1\n\n To see item number \$n, use 'help ${topic}\[\$n\]'. \n\n=cut\n\n";
+       }
+
+       if (@match > 0 and $num_pdl_pod_matches > 1) {
+          print $out "\n=head1 Displaying item $pdl_pod_matchnum:\n\n=head1 --------------------------------------\n\n=cut\n\n";
+       }
+
+       my $m = shift @match;
+
+       my $Ref = $m->[1]{Ref};
+       if ( $Ref =~ /^(Module|Manual|Script): / ) {
+          my $in = IO::File->new("<$m->[1]{File}");
+          print $out join("",<$in>);
+       } else {
+          if(defined $m->[1]{CustomFile}) {
+
+             my $parser= new PDL::Pod::Parser;
+             print $out "=head1 Autoload file \"".$m->[1]{CustomFile}."\"\n\n";
+             $parser->parse_from_file($m->[1]{CustomFile},$out);
+             print $out "\n\n=head2 Docs from\n\n".$m->[1]{CustomFile}."\n\n";
+
+          } else {
+
+             print $out "=head1 Module ",$m->[1]{Module}, "\n\n";
+             $PDL::onlinedoc->funcdocs($m->[0],$out);
+
+          }
+
+       }
     }
   }
 
