@@ -404,7 +404,7 @@ drawn and no control of color or transparency.
 
 =for ref
 
-2D TrueColor Image plot
+2D RGB image plot (see also imag2d)
 
 =for usage
 
@@ -427,7 +427,7 @@ e.g.
 
 =for ref
 
-2D TrueColor Image plot as an object inside a 3D space
+2D RGB image plot as an object inside a 3D space
 
 =for usage
 
@@ -945,6 +945,7 @@ sub get_current_window {
 
 # Get the current graphbox
 sub get_current_graphbox {
+        die "get_current_graphbox: ERROR graphbox is not implemented! \n";
 	my $graph = $PDL::Graphics::TriD::curgraph;
 	if(!defined $graph) {
 		$graph = new PDL::Graphics::TriD::Graph();
