@@ -268,13 +268,17 @@ that contains the number of elements in each table row.
 CFITSIO and several large projects (including NASA's Solar Dynamics
 Observatory) now support an unofficial extension to FITS that stores
 images as a collection of individually compressed tiles within a
-BINTABLE extension.  Such images are detected and can be read
-"successfully" as binary tables that contain the compressed tiles.
-Unpacking/uncompression code is in the works but requires either 
-linking to CFITSIO or reverse-engineering it.
+BINTABLE extension.  These images are automagically uncompressed by
+default, and delivered as if they were normal image files.  You can 
+override this behavior by supplying the "expand" key in the options hash.
+
+Currently, only Rice compression is supported, though there is a framework
+in place for adding other compression schemes.
 
 =for bad
 
+=head3 BAD VALUE HANDLING
+
 If a FITS file contains the C<BLANK> keyword (and has C<BITPIX E<gt> 0>), 
 the piddle will have its bad flag set, and those elements which equal the
 C<BLANK> value will be set bad.  For C<BITPIX E<lt> 0>, any NaN's are
@@ -593,8 +597,6 @@ sub _rfits_image($$$$) {
   my @dims; # Store the dimenions 1..N, compute total number of pixels
   my $i = 1;
   my $size = 1; 
-  my $bscale;
-  my $bzero;
 
 ##second part of the conditional guards against a poorly-written hdr.
   while(defined( $$foo{"NAXIS$i"} ) && $i <= $$foo{"NAXIS"}) {
@@ -627,7 +629,24 @@ sub _rfits_image($$$$) {
     bswap8($pdl) if $pdl->get_datatype == $PDL_D;
   }
   
-  if($opt->{bscale}) {
+  if(exists $opt->{bscale}) {
+      $pdl = treat_bscale($pdl, $foo);
+  }
+  
+  # Header
+  
+  $pdl->sethdr($foo);
+
+  $pdl->hdrcpy($opt->{hdrcpy});
+
+  return $pdl;
+} 
+
+sub treat_bscale($$){
+    my $pdl = shift;
+    my $foo = shift;
+
+
     if ( $PDL::Bad::Status ) {
       # do we have bad values? - needs to be done before BSCALE/BZERO
       # (at least for integers)
@@ -652,6 +671,7 @@ sub _rfits_image($$$$) {
 	if $pdl->badflag() and $PDL::verbose;
     } # if: PDL::Bad::Status
     
+    my ($bscale, $bzero);
     $bscale = $$foo{"BSCALE"}; $bzero = $$foo{"BZERO"};
     print "BSCALE = $bscale &&  BZERO = $bzero\n" if $PDL::verbose;
     $bscale = 1 if (!defined($bscale) || $bscale eq "");
@@ -689,16 +709,9 @@ sub _rfits_image($$$$) {
     $pdl += $bzero  if $bzero  != 0;
     
     delete $$foo{"BSCALE"}; delete $$foo{"BZERO"};
-  }
-  
-  # Header
-  
-  $pdl->sethdr($foo);
+    return $pdl;
+}
 
-  $pdl->hdrcpy($opt->{hdrcpy});
-
-  return $pdl;
-} 
 
 ##########
 # 
@@ -1297,16 +1310,30 @@ our $tile_compressors = {
 				    # Put the compressed tile bitstream into a variable of appropriate type.
 				    # This works by direct copying of the PDL data, which sidesteps local 
 				    # byteswap issues in the usual case that the compressed stream is type 
-				    # byte.  
+				    # byte.  But it does add the extra complication that we have to pad the 
+				    # compressed array out to a factor-of-n elements in certain cases.
 
 				    if( PDL::howbig($compressed->get_datatype) != $bytepix ) {
 					my @dims = $compressed->dims;
-					$dims[0] *= PDL::howbig($compressed->get_datatype) / $bytepix;
-					my $c2 = zeroes( $type_table_2->{$bytepix * 8}, @dims );
+					my $newdim0;
+					my $scaledim0;
+
+					$scaledim0 = $dims[0] * PDL::howbig($compressed->get_datatype) / $bytepix;
+					$newdim0 = pdl($scaledim0)->ceil;
+
+					if($scaledim0 != $newdim0) {
+					    my $padding = zeroes($compressed->type, 
+							      ($newdim0-$scaledim0) * $bytepix / PDL::howbig($compressed->get_datatype), 
+							      @dims[1..$#dims]
+						);
+					    $compressed = $compressed->append($padding);
+					}
+					
+					my $c2 = zeroes( $type_table_2->{$bytepix * 8}, $newdim0, @dims[1..$#dims] );
 
 					my $c2dr = $c2->get_dataref;
 					my $cdr = $compressed->get_dataref;
-					$$c2dr = $$cdr;
+					substr($$c2dr,0,length($$cdr)) = $$cdr;
 					$c2->upd_data;
 					$compressed = $c2;
 				    }
@@ -1470,6 +1497,10 @@ sub _rfits_unpack_zimage($$$) {
 	    $k =~ m/^TFORM/
 	    );
     }
+
+    if(exists $hdr->{bscale}) {
+	$pdl = treat_bscale($pdl, $hdr);
+    }
     $pdl->sethdr($hdr);
 
     return $pdl;
