@@ -2276,7 +2276,7 @@ sub t_hammer {
 
 ######################################################################
 
-=head2 t_vertical
+=head2 t_vertical, t_zenithal -- vertical perspective projection
 
 =for usage
 
@@ -2289,7 +2289,10 @@ sub t_hammer {
 Vertical perspective projection is a generalization of L<gnomonic|/t_gnomonic>
 and L<stereographic|/t_stereographic> projection, and a special case of 
 L<perspective|/t_perspective> projection.  It is a projection from the 
-sphere onto a focal plane at the camera location.  
+sphere onto a tangent plane from a point at the camera location.
+
+Vertical projections are also called "zenithal", and t_zenithal is an 
+alias for t_vertical.
 
 OPTIONS
 
@@ -2471,6 +2474,8 @@ sub t_vertical {
     $me->_finish;
   }
 
+*t_zenithal = \&t_vertical;
+
 ######################################################################
 
 =head2 t_perspective
